"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.command = void 0;
const command_1 = require("../command");
const projectUtils_1 = require("../projectUtils");
const gcp = require("../gcp/frameworks");
const error_1 = require("../error");
const logger_1 = require("../logger");
exports.command = new command_1.Command("stacks:get")
    .description("Get stack details of a Firebase project")
    .option("-l, --location <location>", "App Backend location", "us-central1")
    .option("--s, --stackId <stackId>", "Stack Id", "")
    .action(async (options) => {
    const projectId = (0, projectUtils_1.needProjectId)(options);
    const location = options.location;
    const stackId = options.stackId;
    if (!stackId) {
        throw new error_1.FirebaseError("Stack id can't be empty.");
    }
    let stack;
    try {
        stack = await gcp.getStack(projectId, location, stackId);
        logger_1.logger.info(stack);
    }
    catch (err) {
        throw new error_1.FirebaseError(`Failed to get stack: ${stackId}. Please check the parameters you have provided.`, { original: err });
    }
    return stack;
});
