"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.command = void 0;
const command_1 = require("../command");
const projectUtils_1 = require("../projectUtils");
const gcp = require("../gcp/frameworks");
const error_1 = require("../error");
const logger_1 = require("../logger");
exports.command = new command_1.Command("stacks:list")
    .description("List stacks of a Firebase project.")
    .option("-l, --location <location>", "App Backend location", "us-central1")
    .action(async (options) => {
    const projectId = (0, projectUtils_1.needProjectId)(options);
    const location = options.location;
    let stacks;
    try {
        stacks = await gcp.listStack(projectId, location);
        logger_1.logger.info(stacks);
    }
    catch (err) {
        throw new error_1.FirebaseError(`Unable to list stacks present in project: ${projectId}. Please check the parameters you have provided.`, { original: err });
    }
    return stacks;
});
